# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2019, by Patrick Davey.
# Copyright, 2021-2023, by Samuel Williams.

module Multipart
  module Post
    VERSION = "2.4.0"
  end
end
